render_loaded_tables_scripts

Function render_loaded_tables_scripts 

pub fn render_loaded_tables_scripts(
    num_tables: usize,
    num_scripts: usize,
) -> Option<String>
Take a pair usize, representing the number of tables and number of scripts that have been loaded. If both are 0, returns None. Otherwise, returns a String describing how many of each have been loaded in a nice and correctly pluralized way.